Documentation
¶
Index ¶
- type Circuit
- type Constructor
- type ConstructorStanding
- type Driver
- type DriverStanding
- type Ergast
- func (ergast *Ergast) ConstructorStandings(ctx context.Context, year int) ([]ConstructorStanding, error)
- func (ergast *Ergast) DriverStandings(ctx context.Context, year int) ([]DriverStanding, error)
- func (ergast *Ergast) Laps(ctx context.Context, year int, round string) ([]Lap, error)
- func (ergast *Ergast) QualifyingResults(ctx context.Context, year int, round string) ([]QualifyingResult, error)
- func (ergast *Ergast) Results(ctx context.Context, year int, round string) ([]Result, error)
- func (ergast *Ergast) Schedule(ctx context.Context, year int) ([]Race, error)
- type Lap
- type Location
- type MRData
- type QualifyingResult
- type Race
- type RaceTable
- type Result
- type StandingsTable
- type Timing
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Constructor ¶
type ConstructorStanding ¶ added in v0.2.0
type ConstructorStanding struct {
Position string `xml:"position,attr"`
Points string `xml:"points,attr"`
Wins string `xml:"wins,attr"`
Constructor Constructor `xml:"Constructor"`
}
type Driver ¶
type Driver struct {
DriverId string `xml:"driverId,attr"`
Code string `xml:"code,attr"`
URL string `xml:"url,attr"`
PermanentNumber string `xml:"PermanentNumber"`
GivenName string `xml:"GivenName"`
FamilyName string `xml:"FamilyName"`
DateOfBirth string `xml:"DateOfBirth"`
Nationality string `xml:"Nationality"`
}
type DriverStanding ¶
type DriverStanding struct {
Position string `xml:"position,attr"`
Points string `xml:"points,attr"`
Wins string `xml:"wins,attr"`
Driver Driver `xml:"Driver"`
Constructor Constructor `xml:"Constructor"`
}
type Ergast ¶
Ergast represents the Ergast Developer API.
func (*Ergast) ConstructorStandings ¶ added in v0.2.0
func (ergast *Ergast) ConstructorStandings(ctx context.Context, year int) ([]ConstructorStanding, error)
ConstructorStandings retrieves the constructors standings for a given season `year`.
func (*Ergast) DriverStandings ¶
DriverStandings retrieves the driver standings for a given season `year`.
func (*Ergast) QualifyingResults ¶ added in v0.2.0
type QualifyingResult ¶ added in v0.2.0
type Race ¶
type Race struct {
Season string `xml:"season,attr"`
Round string `xml:"round,attr"`
URL string `xml:"url,attr"`
RaceName string `xml:"RaceName"`
Circuit Circuit `xml:"Circuit"`
Date string `xml:"Date"`
Time string `xml:"Time"`
Results []Result `xml:"ResultsList>Result"`
Laps []Lap `xml:"LapsList>Lap"`
QualifyingResult []QualifyingResult `xml:"QualifyingList>QualifyingResult"`
}
type Result ¶
type Result struct {
Number string `xml:"number,attr"`
Position string `xml:"position,attr"`
Points string `xml:"points,attr"`
Driver Driver `xml:"Driver"`
Constructor Constructor `xml:"Constructor"`
}
type StandingsTable ¶
type StandingsTable struct {
Season string `xml:"season,attr"`
DriverStandings []DriverStanding `xml:"StandingsList>DriverStanding"`
ConstructorStandings []ConstructorStanding `xml:"StandingsList>ConstructorStanding"`
}
Click to show internal directories.
Click to hide internal directories.